@@ -54,7 +54,7 @@ test_that("AsyncVaried - order", {
   aa$request()
   out <- aa$responses()
 
-  expect_is(out, "list")
+  expect_is(out, "asyncresponses")
   expect_is(out[[1]], "HttpResponse")
   expect_is(out[[2]], "HttpResponse")
   expect_is(out[[3]], "HttpResponse")
@@ -106,7 +106,7 @@ test_that("AsyncVaried - streaming to disk works", {
   skip_on_cran()
 
   lst <- c()
-  fun <- function(x) lst <<- c(lst, x)
+  fun <- function(x) lst <<- append(lst, list(x))
   req1 <- HttpRequest$new(url = hb("/get")
   )$get(query = list(foo = "bar"), stream = fun)
   req2 <- HttpRequest$new(url = hb("/get")
@@ -119,8 +119,11 @@ test_that("AsyncVaried - streaming to disk works", {
   expect_identical(out$responses()[[1]]$content, raw(0))
   expect_identical(out$responses()[[2]]$content, raw(0))
 
-  expect_is(lst, "raw")
-  expect_is(rawToChar(lst), "character")
+  expect_is(lst, "list")
+  expect_is(lst[[1]], "list")
+  expect_is(lst[[2]], "list")
+  expect_is(rawToChar(lst[[1]]$content), "character")
+  expect_is(rawToChar(lst[[2]]$content), "character")
 })
 
 
@@ -175,7 +178,6 @@ test_that("AsyncVaried - failure behavior", {
   expect_false(resps[[3]]$success())
 
   expect_match(resps[[1]]$parse("UTF-8"), "resolve host")
-  expect_true(grepl("time", resps[[3]]$parse("UTF-8"), ignore.case = TRUE))
 })
 
 
@@ -204,7 +206,6 @@ test_that("AsyncVaried - failure behavior", {
   expect_false(resps[[2]]$success())
 
   expect_match(resps[[1]]$parse("UTF-8"), "resolve host")
-  expect_true(grepl("time", resps[[2]]$parse("UTF-8"), ignore.case = TRUE))
   
   # cleanup
   closeAllConnections()
@@ -235,7 +236,6 @@ test_that("AsyncVaried - failure behavior", {
   expect_false(resps[[2]]$success())
 
   expect_match(resps[[1]]$parse("UTF-8"), "resolve host")
-  expect_true(grepl("time", resps[[2]]$parse("UTF-8"), ignore.case = TRUE))
 })
 
 # verb method works
@@ -250,3 +250,16 @@ test_that("AsyncVaried verb method works", {
   expect_equal(aa$responses()[[1]]$method, 'get')
   expect_equal(aa$responses()[[2]]$method, 'post')
 })
+
+# verb method works
+test_that("AsyncVaried verb retry", {
+  skip_on_cran()
+
+  req1 <- HttpRequest$new(url = hb("/get"))$retry('get')
+  req2 <- HttpRequest$new(url = hb("/post"))$retry('post')
+
+  aa <- AsyncVaried$new(req1, req2)
+  aa$request()
+  expect_equal(aa$responses()[[1]]$method, 'get')
+  expect_equal(aa$responses()[[2]]$method, 'post')
+})
